==> kubernetes-model-apps-5.0.1-sources.jar: annotations/io/fabric8/kubernetes/api/model/apps/StatefulSetListFluent.java <==
package io.fabric8.kubernetes.api.model.apps;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.model.ListMeta;
import java.util.function.Predicate;
import java.lang.StringBuffer;
import java.lang.Deprecated;
import java.lang.Long;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

public interface StatefulSetListFluent<A extends StatefulSetListFluent<A>> extends Fluent<A> {


    public String getApiVersion();
    public A withApiVersion(String apiVersion);
    public Boolean hasApiVersion();
    public A withNewApiVersion(String arg1);
    public A withNewApiVersion(StringBuilder arg1);
    public A withNewApiVersion(StringBuffer arg1);
    public A addToItems(int index,StatefulSet item);
    public A setToItems(int index,StatefulSet item);
    public A addToItems(StatefulSet... items);
    public A addAllToItems(Collection<StatefulSet> items);
    public A removeFromItems(StatefulSet... items);
    public A removeAllFromItems(Collection<StatefulSet> items);
    public A removeMatchingFromItems(Predicate<StatefulSetBuilder> predicate);
    
/**
 * This method has been deprecated, please use method buildItems instead.
 * @return The buildable object.
 */
@Deprecated public List<StatefulSet> getItems();
    public List<StatefulSet> buildItems();
    public StatefulSet buildItem(int index);
    public StatefulSet buildFirstItem();
    public StatefulSet buildLastItem();
    public StatefulSet buildMatchingItem(Predicate<StatefulSetBuilder> predicate);
    public Boolean hasMatchingItem(Predicate<StatefulSetBuilder> predicate);
    public A withItems(List<StatefulSet> items);
    public A withItems(StatefulSet... items);
    public Boolean hasItems();
    public StatefulSetListFluent.ItemsNested<A> addNewItem();
    public StatefulSetListFluent.ItemsNested<A> addNewItemLike(StatefulSet item);
    public StatefulSetListFluent.ItemsNested<A> setNewItemLike(int index,StatefulSet item);
    public StatefulSetListFluent.ItemsNested<A> editItem(int index);
    public StatefulSetListFluent.ItemsNested<A> editFirstItem();
    public StatefulSetListFluent.ItemsNested<A> editLastItem();
    public StatefulSetListFluent.ItemsNested<A> editMatchingItem(Predicate<StatefulSetBuilder> predicate);
    public String getKind();
    public A withKind(String kind);
    public Boolean hasKind();
    public A withNewKind(String arg1);
    public A withNewKind(StringBuilder arg1);
    public A withNewKind(StringBuffer arg1);
    public ListMeta getMetadata();
    public A withMetadata(ListMeta metadata);
    public Boolean hasMetadata();
    public A withNewMetadata(String _continue,Long remainingItemCount,String resourceVersion,String selfLink);
    public interface ItemsNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,StatefulSetFluent<StatefulSetListFluent.ItemsNested<N>> {

            public N and();
            public N endItem();    }


}

==> kubernetes-model-apps-5.3.0-sources.jar: annotations/io/fabric8/kubernetes/api/model/apps/StatefulSetListFluent.java <==
package io.fabric8.kubernetes.api.model.apps;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.model.ListMeta;
import java.util.function.Predicate;
import java.lang.StringBuffer;
import java.lang.Deprecated;
import java.lang.Long;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

public interface StatefulSetListFluent<A extends StatefulSetListFluent<A>> extends Fluent<A> {


    public String getApiVersion();
    public A withApiVersion(String apiVersion);
    public Boolean hasApiVersion();
    public A withNewApiVersion(StringBuilder arg1);
    public A withNewApiVersion(int[] arg1,int arg2,int arg3);
    public A withNewApiVersion(char[] arg1);
    public A withNewApiVersion(StringBuffer arg1);
    public A withNewApiVersion(byte[] arg1,int arg2);
    public A withNewApiVersion(byte[] arg1);
    public A withNewApiVersion(char[] arg1,int arg2,int arg3);
    public A withNewApiVersion(byte[] arg1,int arg2,int arg3);
    public A withNewApiVersion(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewApiVersion(String arg1);
    public A addToItems(int index,StatefulSet item);
    public A setToItems(int index,StatefulSet item);
    public A addToItems(StatefulSet... items);
    public A addAllToItems(Collection<StatefulSet> items);
    public A removeFromItems(StatefulSet... items);
    public A removeAllFromItems(Collection<StatefulSet> items);
    public A removeMatchingFromItems(Predicate<StatefulSetBuilder> predicate);
    
/**
 * This method has been deprecated, please use method buildItems instead.
 * @return The buildable object.
 */
@Deprecated public List<StatefulSet> getItems();
    public List<StatefulSet> buildItems();
    public StatefulSet buildItem(int index);
    public StatefulSet buildFirstItem();
    public StatefulSet buildLastItem();
    public StatefulSet buildMatchingItem(Predicate<StatefulSetBuilder> predicate);
    public Boolean hasMatchingItem(Predicate<StatefulSetBuilder> predicate);
    public A withItems(List<StatefulSet> items);
    public A withItems(StatefulSet... items);
    public Boolean hasItems();
    public StatefulSetListFluent.ItemsNested<A> addNewItem();
    public StatefulSetListFluent.ItemsNested<A> addNewItemLike(StatefulSet item);
    public StatefulSetListFluent.ItemsNested<A> setNewItemLike(int index,StatefulSet item);
    public StatefulSetListFluent.ItemsNested<A> editItem(int index);
    public StatefulSetListFluent.ItemsNested<A> editFirstItem();
    public StatefulSetListFluent.ItemsNested<A> editLastItem();
    public StatefulSetListFluent.ItemsNested<A> editMatchingItem(Predicate<StatefulSetBuilder> predicate);
    public String getKind();
    public A withKind(String kind);
    public Boolean hasKind();
    public A withNewKind(StringBuilder arg1);
    public A withNewKind(int[] arg1,int arg2,int arg3);
    public A withNewKind(char[] arg1);
    public A withNewKind(StringBuffer arg1);
    public A withNewKind(byte[] arg1,int arg2);
    public A withNewKind(byte[] arg1);
    public A withNewKind(char[] arg1,int arg2,int arg3);
    public A withNewKind(byte[] arg1,int arg2,int arg3);
    public A withNewKind(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewKind(String arg1);
    public ListMeta getMetadata();
    public A withMetadata(ListMeta metadata);
    public Boolean hasMetadata();
    public A withNewMetadata(String _continue,Long remainingItemCount,String resourceVersion,String selfLink);
    public interface ItemsNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,StatefulSetFluent<StatefulSetListFluent.ItemsNested<N>> {

            public N and();
            public N endItem();    }


}
